==> qbittorrent_3.3.1.orig.tar.xz: qbittorrent-3.3.1/src/base/tristatebool.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2015  Vladimir Golovnev <glassez@yandex.ru>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#ifndef TRISTATEBOOL_H
#define TRISTATEBOOL_H

class TriStateBool
{
public:
    enum ValueType
    {
        Undefined = -1,
        False = 0,
        True = 1
    };

    TriStateBool();
    TriStateBool(bool b);
    TriStateBool(ValueType value);

    operator ValueType() const;
    operator bool() const;

private:
    ValueType m_value;
};

#endif // TRISTATEBOOL_H

==> qbittorrent_4.0.3.orig.tar.xz: qbittorrent-4.0.3/src/base/tristatebool.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2015  Vladimir Golovnev <glassez@yandex.ru>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#ifndef TRISTATEBOOL_H
#define TRISTATEBOOL_H

class TriStateBool
{
public:
    static const TriStateBool Undefined;
    static const TriStateBool False;
    static const TriStateBool True;

    TriStateBool() = default;
    TriStateBool(const TriStateBool &other) = default;

    explicit TriStateBool(int value);
    explicit operator int() const;

    TriStateBool &operator=(const TriStateBool &other) = default;
    bool operator==(const TriStateBool &other) const;
    bool operator!=(const TriStateBool &other) const;

private:
    signed char m_value = -1; // Undefined by default
};

#endif // TRISTATEBOOL_H
